@@ -31,8 +31,8 @@
  * Glib gets this wrong, really.  ARM's floating point format is a weird
  * mixture.
  */
-#if defined(__arm__) && !defined(__vfp__) && (G_BYTE_ORDER == G_LITTLE_ENDIAN)
 #define G_ARMFLOAT_ENDIAN 56781234
+#if defined(__arm__) && !defined(__vfp__) && (G_BYTE_ORDER == G_LITTLE_ENDIAN)
 #define G_FLOAT_BYTE_ORDER G_ARMFLOAT_ENDIAN
 #else
 #define G_FLOAT_BYTE_ORDER G_BYTE_ORDER
@@ -41,6 +41,11 @@
 
 static void base64_init (void);
 
+/**
+ * gsf_init :
+ *
+ * Initializes the GSF library
+ */
 void
 gsf_init (void)
 {
@@ -48,6 +53,11 @@ gsf_init (void)
 	base64_init ();
 }
 
+/**
+ * gsf_shutdown:
+ * 
+ * De-intializes the GSF library
+ */
 void
 gsf_shutdown (void)
 {
@@ -86,6 +96,13 @@ gsf_mem_dump (guint8 const *ptr, size_t len)
 	gsf_mem_dump_full (ptr, len, 0);
 }
 
+/**
+ * gsf_input_dump :
+ * @input: a #GsfInput
+ * @dump_as_hex: If TRUE, dump in hexidecmal format
+ *
+ * Dumps @input's contents to STDOUT, optionally in hex format.
+ */
 void
 gsf_input_dump (GsfInput *input, gboolean dump_as_hex)
 {
@@ -107,6 +124,8 @@ gsf_input_dump (GsfInput *input, gboolean dump_as_hex)
 		size -= count;
 		offset += count;
 	}
+	if (!dump_as_hex)
+		fflush (stdout);
 }
 
 guint64
@@ -602,9 +621,13 @@ gsf_base64_encode_simple (guint8 const *data, size_t len)
 	guint8 *out;
 	int state = 0, outlen;
 	unsigned int save = 0;
-	
-	out = g_new (guint8, len * 4 / 3 + 5);
-	outlen = gsf_base64_encode_close (data, len, FALSE, out, &state, &save);
+	gboolean break_lines = TRUE;
+
+	outlen = len * 4 / 3 + 5;
+	if (break_lines) outlen += outlen / 50;
+	out = g_new (guint8, outlen);
+	outlen = gsf_base64_encode_close (data, len, break_lines,
+					  out, &state, &save);
 	out [outlen] = '\0';
 	return out;
 }
